# Pymablock authors

## Current pymablock maintainers

- Isidora Araya Day
- Anton Akhmerov
- Sebastian Miles

## Other contributors

- Daniel Varjas
- Rafał Skolasinski
- Pablo Pérez Piskunow
- Kostas Vilkelis
- Antonio Manesco
- Hugo Kerstens
- Bas Nijholt
- Adam Chaou
- Jörg Behrmann

## Funding

This project was initially developed in [Delft University of Technology](https://www.tudelft.nl/en/), supported by the [Netherlands Organisation for Scientific Research (NWO/OCW)](https://www.nwo.nl/), as part of the Frontiers of Nanoscience program, as well as grants 016.Vidi.189.180 and
OCENW.GROOT.2019.004.
